"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const util_1 = require("util");
const vscode_1 = require("vscode");
const accessAsync = util_1.promisify(fs_1.access);
class VSCEnvironment {
    constructor() {
        this.workspaceConfiguration = vscode_1.workspace.getConfiguration("azurite");
    }
    blobHost() {
        return this.workspaceConfiguration.get("blobHost");
    }
    blobPort() {
        return this.workspaceConfiguration.get("blobPort");
    }
    queueHost() {
        return this.workspaceConfiguration.get("queueHost");
    }
    queuePort() {
        return this.workspaceConfiguration.get("queuePort");
    }
    async location() {
        let location = this.workspaceConfiguration.get("location");
        // When location configuration is not provided, use current opened folder
        if (location === undefined || location === "") {
            if (vscode_1.workspace.workspaceFolders === undefined ||
                vscode_1.workspace.workspaceFolders.length === 0) {
                // location = join(homedir(), "Azurite");
                throw Error(
                // tslint:disable-next-line:max-line-length
                `Invalid workspace location for Azurite. Please open a folder in Visual Studio Code, or provide a valid workspace folder path for Azurite in Visual Studio Code setting "azurite.location"`);
            }
            let folder;
            if (vscode_1.workspace.workspaceFolders.length > 1) {
                folder = await vscode_1.window.showWorkspaceFolderPick({
                    placeHolder: "Select the working directory you wish to use as Azurite workspace location"
                });
                if (folder === undefined) {
                    throw Error(
                    // tslint:disable-next-line:max-line-length
                    `Invalid workspace location for Azurite. Please select a folder in Visual Studio Code, or provide a valid workspace folder path for Azurite in Visual Studio Code setting "azurite.location"`);
                }
            }
            else {
                folder = vscode_1.workspace.workspaceFolders[0];
            }
            location = folder.uri.fsPath;
        }
        await accessAsync(location);
        return location;
    }
    silent() {
        return this.workspaceConfiguration.get("silent") || false;
    }
    loose() {
        return this.workspaceConfiguration.get("loose") || false;
    }
    async debug() {
        return this.workspaceConfiguration.get("debug") || false;
    }
    cert() {
        return this.workspaceConfiguration.get("cert");
    }
    key() {
        return this.workspaceConfiguration.get("key");
    }
    pwd() {
        return this.workspaceConfiguration.get("pwd");
    }
    oauth() {
        return this.workspaceConfiguration.get("oauth");
    }
}
exports.default = VSCEnvironment;
//# sourceMappingURL=VSCEnvironment.js.map