"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const vscode_1 = require("vscode");
const VSCAccessLog_1 = tslib_1.__importDefault(require("./common/VSCAccessLog"));
const VSCNotification_1 = tslib_1.__importDefault(require("./common/VSCNotification"));
const VSCProgress_1 = tslib_1.__importDefault(require("./common/VSCProgress"));
const VSCServerManagerBlob_1 = tslib_1.__importDefault(require("./common/VSCServerManagerBlob"));
const VSCServerManagerQueue_1 = tslib_1.__importDefault(require("./common/VSCServerManagerQueue"));
const VSCStatusBarItem_1 = tslib_1.__importDefault(require("./common/VSCStatusBarItem"));
function activate(context) {
    // Initialize server managers
    const blobServerManager = new VSCServerManagerBlob_1.default();
    const queueServerManager = new VSCServerManagerQueue_1.default();
    // Hook up status bar handlers
    const vscBlobStatusBar = new VSCStatusBarItem_1.default(blobServerManager, vscode_1.window.createStatusBarItem(vscode_1.StatusBarAlignment.Right, 1000));
    const vscQueueStatusBar = new VSCStatusBarItem_1.default(queueServerManager, vscode_1.window.createStatusBarItem(vscode_1.StatusBarAlignment.Right, 1001));
    blobServerManager.addEventListener(vscBlobStatusBar);
    queueServerManager.addEventListener(vscQueueStatusBar);
    // Hook up notification handlers
    const notification = new VSCNotification_1.default();
    blobServerManager.addEventListener(notification);
    queueServerManager.addEventListener(notification);
    // Hook up progress handlers
    blobServerManager.addEventListener(new VSCProgress_1.default());
    queueServerManager.addEventListener(new VSCProgress_1.default());
    // Hook up access log handlers
    blobServerManager.addEventListener(new VSCAccessLog_1.default(blobServerManager.accessChannelStream));
    queueServerManager.addEventListener(new VSCAccessLog_1.default(queueServerManager.accessChannelStream));
    context.subscriptions.push(vscode_1.commands.registerCommand("azurite.start", () => {
        blobServerManager.start();
        queueServerManager.start();
    }), vscode_1.commands.registerCommand("azurite.close", () => {
        blobServerManager.close();
        queueServerManager.close();
    }), vscode_1.commands.registerCommand("azurite.clean", () => {
        blobServerManager.clean();
        queueServerManager.clean();
    }), vscode_1.commands.registerCommand(blobServerManager.getStartCommand(), () => {
        blobServerManager.start();
    }), vscode_1.commands.registerCommand(blobServerManager.getCloseCommand(), () => {
        blobServerManager.close();
    }), vscode_1.commands.registerCommand(blobServerManager.getCleanCommand(), () => {
        blobServerManager.clean();
    }), vscode_1.commands.registerCommand(queueServerManager.getStartCommand(), () => {
        queueServerManager.start();
    }), vscode_1.commands.registerCommand(queueServerManager.getCloseCommand(), () => {
        queueServerManager.close();
    }), vscode_1.commands.registerCommand(queueServerManager.getCleanCommand(), () => {
        queueServerManager.clean();
    }), vscBlobStatusBar.statusBarItem, vscQueueStatusBar.statusBarItem);
}
exports.activate = activate;
// this method is called when your extension is deactivated
function deactivate() {
    /* NOOP */
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map