import ICleaner from "../common/ICleaner";
import ServerBase from "../common/ServerBase";
import BlobConfiguration from "./BlobConfiguration";
/**
 * Default implementation of Azurite Blob HTTP server.
 * This implementation provides a HTTP service based on express framework and LokiJS in memory database.
 *
 * We can create other blob servers by extending abstract Server class and initialize different httpServer,
 * dataStore or requestListenerFactory fields.
 *
 * For example, creating a HTTPS server to accept HTTPS requests, or using other
 * Node.js HTTP frameworks like Koa, or just using another SQL database.
 *
 * @export
 * @class Server
 */
export default class BlobServer extends ServerBase implements ICleaner {
    private readonly metadataStore;
    private readonly extentMetadataStore;
    private readonly extentStore;
    private readonly accountDataStore;
    private readonly gcManager;
    /**
     * Creates an instance of Server.
     *
     * @param {BlobConfiguration} configuration
     * @memberof Server
     */
    constructor(configuration?: BlobConfiguration);
    /**
     * Clean up server persisted data, including Loki metadata database file,
     * Loki extent database file and extent data.
     *
     * @returns {Promise<void>}
     * @memberof BlobServer
     */
    clean(): Promise<void>;
    protected beforeStart(): Promise<void>;
    protected afterStart(): Promise<void>;
    protected beforeClose(): Promise<void>;
    protected afterClose(): Promise<void>;
}
//# sourceMappingURL=BlobServer.d.ts.map