import StorageError from "./StorageError";
/**
 * A factory class maintains all Azure Storage Blob service errors.
 *
 * @export
 * @class StorageErrorFactory
 */
export default class StorageErrorFactory {
    static getContainerNotFound(contextID?: string): StorageError;
    static getRequestEntityTooLarge(contextID?: string): StorageError;
    static getBlockCountExceedsLimit(contextID?: string): StorageError;
    static getContainerAlreadyExists(contextID?: string): StorageError;
    static getBlobAlreadyExists(contextID?: string): StorageError;
    static getBlobNotFound(contextID?: string): StorageError;
    static getInvalidQueryParameterValue(contextID?: string, parameterName?: string, parameterValue?: string, reason?: string): StorageError;
    static getOutOfRangeInput(contextID?: string, parameterName?: string, parameterValue?: string, reason?: string): StorageError;
    static getInvalidOperation(contextID?: string, message?: string): StorageError;
    static getInvalidBlockList(contextID?: string): StorageError;
    static getInvalidAuthenticationInfo(contextID?: string): StorageError;
    static getMd5Mismatch(contextID: string | undefined, userSpecifiedMd5: string, serverCalculatedMd5: string): StorageError;
    static getInvalidPageRange(contextID: string): StorageError;
    static getInvalidLeaseDuration(contextID?: string): StorageError;
    static getInvalidLeaseBreakPeriod(contextID?: string): StorageError;
    static getInvalidId(contextID: string): StorageError;
    static getInvalidBlobOrBlock(contextID?: string): StorageError;
    static getLeaseAlreadyPresent(contextID?: string): StorageError;
    static getLeaseIsBreakingAndCannotBeAcquired(contextID?: string): StorageError;
    static getLeaseNotPresentWithLeaseOperation(contextID?: string): StorageError;
    static getLeaseIdMismatchWithLeaseOperation(contextID?: string): StorageError;
    static getLeaseIsBrokenAndCannotBeRenewed(contextID?: string): StorageError;
    static getLeaseIsBreakingAndCannotBeChanged(contextID?: string): StorageError;
    static getContainerLeaseIdMissing(contextID?: string): StorageError;
    static getContainerLeaseIdMismatchWithContainerOperation(contextID?: string): StorageError;
    static getContainerLeaseLost(contextID?: string): StorageError;
    static getBlobLeaseIdMismatchWithLeaseOperation(contextID: string): StorageError;
    static getBlobLeaseNotPresentWithLeaseOperation(contextID: string): StorageError;
    static getBlobSnapshotsPresent(contextID?: string): StorageError;
    static getBlobLeaseIdMissing(contextID?: string): StorageError;
    static getBlobLeaseIdMismatchWithBlobOperation(contextID?: string): StorageError;
    static getBlobLeaseLost(contextID?: string): StorageError;
    static getAuthorizationFailure(contextID: string): StorageError;
    static getAuthenticationFailed(contextID: string | undefined, authenticationErrorDetail: string): StorageError;
    static getBlobInvalidBlobType(contextID?: string): StorageError;
    static getAccessTierNotSupportedForBlobType(contextID: string): StorageError;
    static getMultipleConditionHeadersNotSupported(contextID: string): StorageError;
    static getBlobSnapshotsPresent_hassnapshot(contextID: string): StorageError;
    static getBlobCannotChangeToLowerTier(contextID: string): StorageError;
    static getBlobBlobTierInadequateForContentLength(contextID: string): StorageError;
    static getAuthorizationSourceIPMismatch(contextID: string): StorageError;
    static getAuthorizationProtocolMismatch(contextID: string): StorageError;
    static getAuthorizationPermissionMismatch(contextID: string): StorageError;
    static getAuthorizationServiceMismatch(contextID: string): StorageError;
    static getAuthorizationResourceTypeMismatch(contextID: string): StorageError;
    static getFeatureVersionMismatch(contextID: string): StorageError;
    static getCopyIdMismatch(contextID: string): StorageError;
    static getNoPendingCopyOperation(contextID: string): StorageError;
    static getSnapshotsPresent(contextID: string): StorageError;
    static getConditionNotMet(contextID: string): StorageError;
    static getMaxBlobSizeConditionNotMet(contextID?: string): StorageError;
    static getAppendPositionConditionNotMet(contextID?: string): StorageError;
    static getSequenceNumberConditionNotMet(contextID: string): StorageError;
    static getNotModified(contextID: string): StorageError;
    static getUnsatisfiableCondition(contextID: string): StorageError;
    static getInvalidHeaderValue(contextID?: string, additionalMessages?: {
        [key: string]: string;
    }): StorageError;
    static getBlobArchived(contextID?: string, additionalMessages?: {
        [key: string]: string;
    }): StorageError;
    static getInvalidCorsHeaderValue(contextID?: string, additionalMessages?: {
        [key: string]: string;
    }): StorageError;
    static corsPreflightFailure(contextID?: string, additionalMessages?: {
        [key: string]: string;
    }): StorageError;
}
//# sourceMappingURL=StorageErrorFactory.d.ts.map