import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IContainerHandler from "../generated/handlers/IContainerHandler";
import BaseHandler from "./BaseHandler";
/**
 * ContainerHandler handles Azure Storage Blob container related requests.
 *
 * @export
 * @class ContainerHandler
 * @implements {IHandler}
 */
export default class ContainerHandler extends BaseHandler implements IContainerHandler {
    /**
     * Create container.
     *
     * @param {Models.ContainerCreateOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerCreateResponse>}
     * @memberof ContainerHandler
     */
    create(options: Models.ContainerCreateOptionalParams, context: Context): Promise<Models.ContainerCreateResponse>;
    /**
     * get container properties
     *
     * @param {Models.ContainerGetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerGetPropertiesResponse>}
     * @memberof ContainerHandler
     */
    getProperties(options: Models.ContainerGetPropertiesOptionalParams, context: Context): Promise<Models.ContainerGetPropertiesResponse>;
    /**
     * get container properties with headers
     *
     * @param {Models.ContainerGetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerGetPropertiesResponse>}
     * @memberof ContainerHandler
     */
    getPropertiesWithHead(options: Models.ContainerGetPropertiesOptionalParams, context: Context): Promise<Models.ContainerGetPropertiesResponse>;
    /**
     * Delete container.
     *
     * @param {Models.ContainerDeleteMethodOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerDeleteResponse>}
     * @memberof ContainerHandler
     */
    delete(options: Models.ContainerDeleteMethodOptionalParams, context: Context): Promise<Models.ContainerDeleteResponse>;
    /**
     * Set container metadata.
     *
     * @param {Models.ContainerSetMetadataOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerSetMetadataResponse>}
     * @memberof ContainerHandler
     */
    setMetadata(options: Models.ContainerSetMetadataOptionalParams, context: Context): Promise<Models.ContainerSetMetadataResponse>;
    /**
     * Get container access policy.
     *
     * @param {Models.ContainerGetAccessPolicyOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerGetAccessPolicyResponse>}
     * @memberof ContainerHandler
     */
    getAccessPolicy(options: Models.ContainerGetAccessPolicyOptionalParams, context: Context): Promise<Models.ContainerGetAccessPolicyResponse>;
    /**
     * set container access policy
     *
     * @param {Models.ContainerSetAccessPolicyOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerSetAccessPolicyResponse>}
     * @memberof ContainerHandler
     */
    setAccessPolicy(options: Models.ContainerSetAccessPolicyOptionalParams, context: Context): Promise<Models.ContainerSetAccessPolicyResponse>;
    /**
     * Acquire container lease.
     *
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/lease-container
     *
     * @param {Models.ContainerAcquireLeaseOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerAcquireLeaseResponse>}
     * @memberof ContainerHandler
     */
    acquireLease(options: Models.ContainerAcquireLeaseOptionalParams, context: Context): Promise<Models.ContainerAcquireLeaseResponse>;
    /**
     * Release container lease.
     *
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/lease-container
     *
     * @param {string} leaseId
     * @param {Models.ContainerReleaseLeaseOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerReleaseLeaseResponse>}
     * @memberof ContainerHandler
     */
    releaseLease(leaseId: string, options: Models.ContainerReleaseLeaseOptionalParams, context: Context): Promise<Models.ContainerReleaseLeaseResponse>;
    /**
     * Renew container lease.
     *
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/lease-container
     *
     * @param {string} leaseId
     * @param {Models.ContainerRenewLeaseOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerRenewLeaseResponse>}
     * @memberof ContainerHandler
     */
    renewLease(leaseId: string, options: Models.ContainerRenewLeaseOptionalParams, context: Context): Promise<Models.ContainerRenewLeaseResponse>;
    /**
     * Break container lease.
     *
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/lease-container
     *
     * @param {Models.ContainerBreakLeaseOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerBreakLeaseResponse>}
     * @memberof ContainerHandler
     */
    breakLease(options: Models.ContainerBreakLeaseOptionalParams, context: Context): Promise<Models.ContainerBreakLeaseResponse>;
    /**
     * Change container lease.
     *
     * @see https://docs.microsoft.com/en-us/rest/api/storageservices/lease-container
     *
     * @param {string} leaseId
     * @param {string} proposedLeaseId
     * @param {Models.ContainerChangeLeaseOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerChangeLeaseResponse>}
     * @memberof ContainerHandler
     */
    changeLease(leaseId: string, proposedLeaseId: string, options: Models.ContainerChangeLeaseOptionalParams, context: Context): Promise<Models.ContainerChangeLeaseResponse>;
    /**
     * list blobs flat segments
     *
     * @param {Models.ContainerListBlobFlatSegmentOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerListBlobFlatSegmentResponse>}
     * @memberof ContainerHandler
     */
    listBlobFlatSegment(options: Models.ContainerListBlobFlatSegmentOptionalParams, context: Context): Promise<Models.ContainerListBlobFlatSegmentResponse>;
    /**
     * List blobs hierarchy.
     *
     * @param {string} delimiter
     * @param {Models.ContainerListBlobHierarchySegmentOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ContainerListBlobHierarchySegmentResponse>}
     * @memberof ContainerHandler
     */
    listBlobHierarchySegment(delimiter: string, options: Models.ContainerListBlobHierarchySegmentOptionalParams, context: Context): Promise<Models.ContainerListBlobHierarchySegmentResponse>;
    /**
     * get account info
     *
     * @param {Context} context
     * @returns {Promise<Models.ContainerGetAccountInfoResponse>}
     * @memberof ContainerHandler
     */
    getAccountInfo(context: Context): Promise<Models.ContainerGetAccountInfoResponse>;
    /**
     * get account info with headers
     *
     * @param {Context} context
     * @returns {Promise<Models.ContainerGetAccountInfoResponse>}
     * @memberof ContainerHandler
     */
    getAccountInfoWithHead(context: Context): Promise<Models.ContainerGetAccountInfoResponse>;
}
//# sourceMappingURL=ContainerHandler.d.ts.map