/// <reference types="node" />
import IExtentStore from "../../common/persistence/IExtentStore";
import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IPageBlobHandler from "../generated/handlers/IPageBlobHandler";
import ILogger from "../generated/utils/ILogger";
import IBlobMetadataStore from "../persistence/IBlobMetadataStore";
import BaseHandler from "./BaseHandler";
import IPageBlobRangesManager from "./IPageBlobRangesManager";
/**
 * PageBlobHandler handles Azure Storage PageBlob related requests.
 *
 * @export
 * @class PageBlobHandler
 * @extends {BaseHandler}
 * @implements {IPageBlobHandler}
 */
export default class PageBlobHandler extends BaseHandler implements IPageBlobHandler {
    private readonly rangesManager;
    constructor(metadataStore: IBlobMetadataStore, extentStore: IExtentStore, logger: ILogger, rangesManager: IPageBlobRangesManager);
    uploadPagesFromURL(sourceUrl: string, sourceRange: string, contentLength: number, range: string, options: Models.PageBlobUploadPagesFromURLOptionalParams, context: Context): Promise<Models.PageBlobUploadPagesFromURLResponse>;
    create(contentLength: number, blobContentLength: number, options: Models.PageBlobCreateOptionalParams, context: Context): Promise<Models.PageBlobCreateResponse>;
    uploadPages(body: NodeJS.ReadableStream, contentLength: number, options: Models.PageBlobUploadPagesOptionalParams, context: Context): Promise<Models.PageBlobUploadPagesResponse>;
    clearPages(contentLength: number, options: Models.PageBlobClearPagesOptionalParams, context: Context): Promise<Models.PageBlobClearPagesResponse>;
    getPageRanges(options: Models.PageBlobGetPageRangesOptionalParams, context: Context): Promise<Models.PageBlobGetPageRangesResponse>;
    getPageRangesDiff(prevsnapshot: string, options: Models.PageBlobGetPageRangesDiffOptionalParams, context: Context): Promise<Models.PageBlobGetPageRangesDiffResponse>;
    resize(blobContentLength: number, options: Models.PageBlobResizeOptionalParams, context: Context): Promise<Models.PageBlobResizeResponse>;
    updateSequenceNumber(sequenceNumberAction: Models.SequenceNumberActionType, options: Models.PageBlobUpdateSequenceNumberOptionalParams, context: Context): Promise<Models.PageBlobUpdateSequenceNumberResponse>;
    copyIncremental(copySource: string, options: Models.PageBlobCopyIncrementalOptionalParams, context: Context): Promise<Models.PageBlobCopyIncrementalResponse>;
}
//# sourceMappingURL=PageBlobHandler.d.ts.map