import { PageRange } from "../generated/artifacts/models";
import { PersistencyPageRange } from "../persistence/IBlobMetadataStore";
import IPageBlobRangesManager from "./IPageBlobRangesManager";
/********** Ranges Merging Strategy ************/
export default class PageBlobRangesManager implements IPageBlobRangesManager {
    mergeRange(ranges: PersistencyPageRange[], range: PersistencyPageRange): void;
    clearRange(ranges: PersistencyPageRange[], range: PageRange): void;
    /**
     * This method will not modify values of parameter ranges.
     *
     * @param {PersistencyPageRange[]} ranges
     * @param {PageRange} range
     * @returns {PersistencyPageRange[]}
     * @memberof PageBlobRangesManager
     */
    cutRanges(ranges: PersistencyPageRange[], range: PageRange): PersistencyPageRange[];
    fillZeroRanges(ranges: PersistencyPageRange[], range: PageRange): PersistencyPageRange[];
    /**
     * Select overlapped ranges based on binary search.
     *
     * @public
     * @param {PersistencyPageRange[]} ranges Existing ranges
     * @param {number} start Start offset of the new range, inclusive
     * @param {number} end End offset of the new range, inclusive
     * @returns {[number, number]} Impacted start and end ranges indexes tuple
     *                             When no impacted ranges found, will return indexes
     *                             for 2 closet existing ranges
     *                             [FirstLargerRangeIndex, FirstSmallerRangeIndex]
     * @memberof PageBlobRangesManager
     */
    selectImpactedRanges(ranges: PersistencyPageRange[], start: number, end: number): [number, number];
    /**
     * Locate first impacted range for a given position.
     *
     * @public
     * @param {PersistencyPageRange[]} ranges
     * @param {number} searchStart Index of start range in ranges array, inclusive
     * @param {number} searchEnd Index of end range in ranges array, exclusive
     * @param {number} position First range index covers or larger than position will be returned
     * @returns {number} Index of first impacted range or Infinity for no results
     * @memberof PageBlobHandler
     */
    locateFirstImpactedRange(ranges: PersistencyPageRange[], searchStart: number, searchEnd: number, position: number): number;
    /**
     * Locate last impacted range for a given position.
     *
     * @public
     * @param {PersistencyPageRange[]} ranges
     * @param {number} searchStart Index of start range in ranges array, inclusive
     * @param {number} searchEnd Index of end range in ranges array, exclusive
     * @param {number} position Last range index covers or less than position will be returned
     * @returns {number} Index of first impacted range or -1 for no results
     * @memberof PageBlobHandler
     */
    locateLastImpactedRange(ranges: PersistencyPageRange[], searchStart: number, searchEnd: number, position: number): number;
    positionInRange(range: PersistencyPageRange, position: number): boolean;
}
//# sourceMappingURL=PageBlobRangesManager.d.ts.map