import { Options as SequelizeOptions } from "sequelize";
import IExtentMetadataStore, { IExtentModel } from "./IExtentMetadataStore";
/**
 * A SQL based extent metadata storage implementation based on Sequelize.
 * Refer to CONTRIBUTION.md for how to setup SQL database environment.
 *
 * @export
 * @class SqlExtentMetadataStore
 * @implements {IExtentMetadataStore}
 */
export default class SqlExtentMetadataStore implements IExtentMetadataStore {
    private initialized;
    private closed;
    private readonly sequelize;
    /**
     * Creates an instance of SqlExtentMetadataStore.
     *
     * @param {string} connectionURI For example, "postgres://user:pass@example.com:5432/dbname"
     * @param {SequelizeOptions} [sequelizeOptions]
     * @memberof SqlBlobMetadataStore
     */
    constructor(connectionURI: string, sequelizeOptions?: SequelizeOptions);
    init(): Promise<void>;
    isInitialized(): boolean;
    close(): Promise<void>;
    isClosed(): boolean;
    clean(): Promise<void>;
    /**
     * Update the extent status in DB. A new item will be created if the extent does not exists.
     *
     * @param {IExtentModel} extent
     * @returns {Promise<void>}
     * @memberof LokiExtentMetadata
     */
    updateExtent(extent: IExtentModel): Promise<void>;
    /**
     *
     * List extents.
     * @param {string} [id]
     * @param {number} [maxResults]
     * @param {(number | undefined)} [marker]
     * @param {Date} [queryTime]
     * @param {number} [protectTimeInMs]
     * @returns {(Promise<[IExtentModel[], number | undefined]>)}
     * @memberof SqlExtentMetadataStore
     */
    listExtents(id?: string, maxResults?: number, marker?: number | string | undefined, queryTime?: Date, protectTimeInMs?: number): Promise<[IExtentModel[], number | undefined]>;
    /**
     * Delete the extent metadata from DB with the extentId.
     *
     * @param {string} extentId
     * @returns {Promise<void>}
     * @memberof IExtentMetadata
     */
    deleteExtent(extentId: string): Promise<void>;
    /**
     * Get the locationId for a given extentId.
     *
     * @param {string} extentId
     * @returns {Promise<string>}
     * @memberof IExtentMetadata
     */
    getExtentLocationId(extentId: string): Promise<string>;
    iteratorExtents(): AsyncIterator<string[]>;
    private getModelValue;
}
//# sourceMappingURL=SqlExtentMetadataStore.d.ts.map