import MiddlewareError from "../generated/errors/MiddlewareError";
/**
 * Represents an Azure Storage Server Error.
 *
 * @export
 * @class StorageError
 * @extends {MiddlewareError}
 */
export default class StorageError extends MiddlewareError {
    readonly storageErrorCode: string;
    readonly storageErrorMessage: string;
    readonly storageRequestID: string;
    /**
     * Creates an instance of StorageError.
     *
     * @param {number} statusCode HTTP response status code
     * @param {string} storageErrorCode Azure Storage error code, will be in response body and header
     * @param {string} storageErrorMessage Azure Storage error message
     * @param {string} storageRequestID Azure Storage server request ID
     * @param {{ [key: string]: string }} [storageAdditionalErrorMessages={}]
     *                                  Additional error messages will be included in XML body
     * @memberof StorageError
     */
    constructor(statusCode: number, storageErrorCode: string, storageErrorMessage: string, storageRequestID: string, storageAdditionalErrorMessages?: {
        [key: string]: string;
    });
}
//# sourceMappingURL=StorageError.d.ts.map