import { ErrorRequestHandler, RequestHandler } from "express";
import IHandlers from "./handlers/IHandlers";
import MiddlewareFactory from "./MiddlewareFactory";
import ILogger from "./utils/ILogger";
/**
 * ExpressMiddlewareFactory will generate Express compatible middleware according to swagger definitions.
 * Generated middleware MUST be used by strict order:
 *  * dispatchMiddleware
 *  * DeserializerMiddleware
 *  * HandlerMiddleware
 *  * SerializerMiddleware
 *  * ErrorMiddleware
 *  * EndMiddleware
 *
 * @export
 * @class MiddlewareFactory
 */
export default class ExpressMiddlewareFactory extends MiddlewareFactory {
    private readonly contextPath;
    /**
     * Creates an instance of MiddlewareFactory.
     *
     * @param {ILogger} logger A valid logger
     * @param {string} [contextPath="default_context"] Optional. res.locals[contextPath] will be used to hold context
     * @memberof MiddlewareFactory
     */
    constructor(logger: ILogger, contextPath?: string);
    /**
     * DispatchMiddleware is the 1s middleware should be used among other generated middleware.
     *
     * @returns {RequestHandler}
     * @memberof MiddlewareFactory
     */
    createDispatchMiddleware(): RequestHandler;
    /**
     * DeserializerMiddleware is the 2nd middleware should be used among other generated middleware.
     *
     * @returns {RequestHandler}
     * @memberof MiddlewareFactory
     */
    createDeserializerMiddleware(): RequestHandler;
    /**
     * HandlerMiddleware is the 3rd middleware should be used among other generated middleware.
     *
     * @param {IHandlers} handlers
     * @returns {RequestHandler}
     * @memberof MiddlewareFactory
     */
    createHandlerMiddleware(handlers: IHandlers): RequestHandler;
    /**
     * SerializerMiddleware is the 4st middleware should be used among other generated middleware.
     *
     * @returns {RequestHandler}
     * @memberof MiddlewareFactory
     */
    createSerializerMiddleware(): RequestHandler;
    /**
     * ErrorMiddleware is the 5st middleware should be used among other generated middleware.
     *
     * @returns {ErrorRequestHandler}
     * @memberof MiddlewareFactory
     */
    createErrorMiddleware(): ErrorRequestHandler;
    /**
     * EndMiddleware is the 6st middleware should be used among other generated middleware.
     *
     * @returns {RequestHandler}
     * @memberof MiddlewareFactory
     */
    createEndMiddleware(): RequestHandler;
}
//# sourceMappingURL=ExpressMiddlewareFactory.d.ts.map