import * as Models from "../generated/artifacts/models";
import Context from "../generated/Context";
import IServiceHandler from "../generated/handlers/IServiceHandler";
import BaseHandler from "./BaseHandler";
/**
 * ServiceHandler handles Azure Storage queue service related requests.
 *
 * @export
 * @class ServiceHandler
 * @implements {IHandler}
 */
export default class ServiceHandler extends BaseHandler implements IServiceHandler {
    /**
     * Default listing queues max number.
     *
     * @private
     * @memberof ServiceHandler
     */
    private readonly LIST_QUEUES_MAX_RESULTS_DEFAULT;
    /**
     * Default service properties.
     *
     * @private
     * @memberof ServiceHandler
     */
    private readonly defaultServiceProperties;
    /**
     * Set blob service properties.
     *
     * @param {Models.StorageServiceProperties} storageServiceProperties
     * @param {Models.ServiceSetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceSetPropertiesResponse>}
     * @memberof ServiceHandler
     */
    setProperties(storageServiceProperties: Models.StorageServiceProperties, options: Models.ServiceSetPropertiesOptionalParams, context: Context): Promise<Models.ServiceSetPropertiesResponse>;
    /**
     * Get queue service properties.
     *
     * @param {Models.ServiceGetPropertiesOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceGetPropertiesResponse>}
     * @memberof ServiceHandler
     */
    getProperties(options: Models.ServiceGetPropertiesOptionalParams, context: Context): Promise<Models.ServiceGetPropertiesResponse>;
    getStatistics(options: Models.ServiceGetStatisticsOptionalParams, context: Context): Promise<Models.ServiceGetStatisticsResponse>;
    /**
     * List queues.
     *
     * @param {Models.ServiceListQueuesSegmentOptionalParams} options
     * @param {Context} context
     * @returns {Promise<Models.ServiceListQueuesSegmentResponse>}
     * @memberof ServiceHandler
     */
    listQueuesSegment(options: Models.ServiceListQueuesSegmentOptionalParams, context: Context): Promise<Models.ServiceListQueuesSegmentResponse>;
}
//# sourceMappingURL=ServiceHandler.d.ts.map